@@ -9,6 +9,7 @@ from . import database, models, tools, forward_sessions
 from .cli_autocomplete import ac_schemas, ac_active_schemas, sc_active_hosts, sc_active_remote_port
 from .cli_session import prepare_sessions_table
 from .forward_sessions import show_active_sessions
+from sqlalchemy.orm.session import make_transient
 
 app = typer.Typer(no_args_is_help=True)
 db = database.SessionLocal()
@@ -109,6 +110,41 @@ def index(schema_filter: str = typer.Argument(None, autocompletion=ac_schemas)):
     rich.print(table)
 
 
+@app.command()
+def clone(schema_id: int = typer.Argument(..., help='Schema ID'),
+          group_id: int = typer.Option(None, help='Group ID'),
+          name: str = typer.Option(None, help='Schema name'),
+          label: str = typer.Option(None, help='Schema label'),):
+
+    schema_original = models.Schema.find_by_id(schema_id)
+    if schema_original is None:
+        print(f"Schema {schema_id} not found")
+        exit(3)
+
+    if group_id is None:
+        group_id = schema_original.group_id
+
+    group = models.Group.find_by_id(group_id)
+    if not group:
+        print(f"Group {group_id} not found")
+        exit(3)
+
+    print(f"Clone schema {schema_original.name}")
+    if not name:
+        name = f"{schema_original.name}_clone"
+
+    if not label:
+        label = f"{schema_original.label} clone"
+    schema_clone = models.Schema(name=name, label=label)
+    group.schemas.append(schema_clone)
+
+    for session_original in schema_original.sessions:
+        session_clone = models.Session.clone(session_original)
+        schema_clone.sessions.append(session_clone)
+
+    models.db_session.commit()
+
+
 @app.command()
 def delete(schema_id: int = typer.Argument(None, help='Schema ID'),
            force: bool = typer.Option(False, help="Force delete")):
