@@ -9,7 +9,7 @@ db_session = SessionLocal()
 class Group(BaseModelDB):
     name = Column(String, unique=True, nullable=False)
     label = Column(String)
-    schemas = relationship('Schema', back_populates='group')
+    schemas = relationship('Schema', back_populates='group', cascade="all,delete")
 
     @staticmethod
     def delete(record: 'Group'):
@@ -64,7 +64,7 @@ class Schema(BaseModelDB):
     active = Column(Boolean, index=True)
     group_id = Column(Integer, ForeignKey('group.id'))
     group = relationship('Group', back_populates='schemas')
-    sessions = relationship('Session', back_populates='schema')
+    sessions = relationship('Session', cascade="all,delete", back_populates='schema')
 
     @staticmethod
     def delete(schema: 'Schema'):
@@ -128,9 +128,20 @@ class Session(BaseModelDB):
     local_port_dynamic = Column(Boolean, default=False)
     url_format = Column(String)
     auto_start = Column(Boolean, index=True, default=True)
-    schema = relationship('Schema', back_populates='sessions')
+    schema = relationship('Schema', cascade="all,delete", back_populates='sessions')
     _connected: bool = False
 
+    @staticmethod
+    def clone(row):
+        data = {}
+        for column in row.__table__.columns:
+            if column.name in ['id']:
+                continue
+
+            data[column.name] = getattr(row, column.name)
+
+        return Session(**data)
+
     @staticmethod
     def delete(session: 'Session'):
         db_session.delete(session)
@@ -232,6 +243,14 @@ class Session(BaseModelDB):
 
 def init_database():
     BaseModelDB.metadata.create_all(engine)
+    group = Group.find_by_name('pfm-system')
+    if not group:
+        print(f"Group missing {group}")
+        group = Group(name="pfm-system", label="System")
+        schema = Schema(name="pfm-ephemeral", label="Ephemeral sessions")
+        group.schemas.append(schema)
+        Group.add(group)
+        db_session.commit()
 
 
 def reset_database():
